
Django OIDC Provider
####################

Django OIDC Provider can help you providing out of the box all the endpoints, data and logic needed to add OpenID Connect capabilities to your Django projects.

Read docs for more info.

https://github.com/juanifioren/django-oidc-provider/blob/master/DOC.md

See changelog here.

https://github.com/juanifioren/django-oidc-provider/blob/master/CHANGELOG.md

************
Contributing
************

We love contributions, so please feel free to fix bugs, improve things, provide documentation. Just submit a Pull Request.
